@@ -10,6 +10,7 @@ from validate_docbr import CNPJ
 
 from snatch.base.data import BaseData
 from snatch.helpers.only_numbers import only_numbers
+from snatch.helpers.time_it import time_it
 
 
 @dataclass
@@ -150,6 +151,7 @@ class BaseSnatch:
         except Timeout as error:
             return self._format_timeout_response(error.request.url)
 
+    @time_it
     def last_valid(self, timeout: Optional[int] = None):
         """Return last valid DataSource integration for TaxId.
 
@@ -164,6 +166,7 @@ class BaseSnatch:
             timeout = self.default_timeout
         return self._last_valid(timeout=timeout)
 
+    @time_it
     def get_data(
         self, timeout: Optional[int] = None, max_days_old: Optional[int] = None
     ):
@@ -188,7 +191,6 @@ class BaseSnatch:
         :param timeout: Time in seconds before timeout connection. Default: 60 seconds.
         :return: DataSource Data Object
         """
-        start_time = arrow.utcnow()
         if not timeout:
             timeout = self.default_timeout
 
@@ -200,19 +202,13 @@ class BaseSnatch:
 
         # Check Status
         if data.integration_status in ["SUCCESS", "TIMEOUT", "CONN_ERROR"]:
-            end_time = arrow.utcnow()
-            data.timeit = (end_time - start_time).seconds
             return data
 
         if data.integration_status == "WAITING":
             wait_data = self._waiter(timeout=timeout)
-            end_time = arrow.utcnow()
-            wait_data.timeit = (end_time - start_time).seconds
             return wait_data
 
         # Status: NOT_FOUND, ERROR or EXPIRED
         self._post_new_prospect(timeout)
         wait_data = self._waiter(timeout=timeout)
-        end_time = arrow.utcnow()
-        wait_data.timeit = (end_time - start_time).seconds
         return wait_data
