@@ -7,7 +7,8 @@ import boto3
 from asbool import asbool
 from botocore.config import Config
 from loguru import logger
-from stela.utils import merge_dicts
+
+from snatch.helpers.merge_dicts import merge_dicts
 
 
 @dataclass
